Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3157)

Unified Diff: chrome/browser/ui/webui/chromeos/login/network_screen_handler.cc

Issue 1887953002: Revert of [Merge to M50] Enable bootstrapping feature by default. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2661
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/webui/chromeos/login/host_pairing_screen_handler.cc ('k') | chrome/common/pref_names.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/webui/chromeos/login/network_screen_handler.cc
diff --git a/chrome/browser/ui/webui/chromeos/login/network_screen_handler.cc b/chrome/browser/ui/webui/chromeos/login/network_screen_handler.cc
index 3d54219f954aa72550098b0d54fc4ca774cfc78c..5d02864a9b918527afc1007a0678d99a34f9fa00 100644
--- a/chrome/browser/ui/webui/chromeos/login/network_screen_handler.cc
+++ b/chrome/browser/ui/webui/chromeos/login/network_screen_handler.cc
@@ -207,15 +207,21 @@
// So we need to disable activation of login layouts if we are already in
// active user session.
//
- // 3) This is the bootstrapping process for a "Slave" device. The locale &
- // input of the "Slave" device is set up by a "Master" device. In this case we
- // don't want EnableLoginLayout() to reset the input method to the hardware
- // default method.
- const bool is_slave = g_browser_process->local_state()->GetBoolean(
- prefs::kOobeControllerDetected);
+ // 3) This is the bootstrapping process for the remora/"Slave" device. The
+ // locale & input of the remora/"Slave" device is set up by a shark/"Master"
+ // device. In this case we don't want EnableLoginLayout() to reset the input
+ // method to the hardware default method.
+ const bool is_remora = g_browser_process->platform_part()
+ ->browser_policy_connector_chromeos()
+ ->GetDeviceCloudPolicyManager()
+ ->IsRemoraRequisition();
+
+ const bool is_slave = base::CommandLine::ForCurrentProcess()->HasSwitch(
+ chromeos::switches::kOobeBootstrappingSlave);
const bool enable_layouts =
- !user_manager::UserManager::Get()->IsUserLoggedIn() && !is_slave;
+ !user_manager::UserManager::Get()->IsUserLoggedIn() && !is_slave &&
+ !is_remora;
dict->Set("languageList", language_list.release());
dict->Set(
« no previous file with comments | « chrome/browser/ui/webui/chromeos/login/host_pairing_screen_handler.cc ('k') | chrome/common/pref_names.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698